@@ -38,6 +38,8 @@ cpl_imagelist * kmos_priv_sky_tweak(
         float                       min_frac,
         int                         tbsub,
         int                         ifu_nr,
-        int                         skip_last) ;
+        int                         skip_last,
+        int                         stretch,
+        int                         plot) ;
 
 #endif
