@@ -106,23 +106,6 @@ static char kmos_flat_description[] =
 "this pattern is probably to be found in the optical path the light is\n"
 "traversing.\n"
 "\n"
-"The behaviour of this fitting step can be influenced via environment\n"
-"parameters:\n"
-"* KF_ALLPARS (default: 1)\n"
-"  When set to 1 all coefficients of the polynomial of an edge are to be\n"
-"  corrected, also when just one of these coefficients is an outlier. When\n"
-"  set to 0 only the outlier is to be corrected.\n"
-"* KF_CH (default: 1)\n"
-"  When set to 1 chebyshev polynomials are used to fit the fitted parameters.\n"
-"  When set to 0 normal polynomials are used.\n"
-"* KF_SIDES (default: 2)\n"
-"  This variable can either be set to 1 or 2. When set to 2 the left and\n"
-"  right edges are examined individually. When set to 1 all edges are\n"
-"  examined as one group.\n"
-"* KF_FACTOR(default: 4)\n"
-"  This factor defines the threshold factor. All parameters deviating \n"
-"  KF_FACTOR*stddev are to be corrected\n"
-"\n"
 "BASIC PARAMETERS:\n"
 "-----------------\n"
 "--badpix_thresh\n"
@@ -464,7 +447,7 @@ static int kmos_flat(cpl_parameterlist *parlist, cpl_frameset *frameset)
     }
 
     /* Identify the RAW and CALIB frames in the input frameset */
-    if (kmo_dfs_set_groups(frameset, "kmos_flat") != 1) {
+    if (kmo_dfs_set_groups(frameset) != 1) {
         cpl_msg_error(__func__, "Cannot identify RAW and CALIB frames") ;
         cpl_error_set(__func__, CPL_ERROR_ILLEGAL_INPUT) ;
         return -1 ;
