@@ -388,6 +388,15 @@ static int kmos_sci_red_create(cpl_plugin *plugin)
     cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
     cpl_parameterlist_append(recipe->parameters, p);
 
+    /* --stretch_sky */
+    p = cpl_parameter_new_value("kmos.kmos_sci_red.stretch_sky",
+            CPL_TYPE_INT, 
+            "Stretch sky in the sky tweaking (0-no,1-yes,2-force)",
+            "kmos.kmos_sci_red", 0);
+    cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "stretch");
+    cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
+    cpl_parameterlist_append(recipe->parameters, p);
+
     /* --tbsub */
     p = cpl_parameter_new_value("kmos.kmos_sci_red.tbsub", CPL_TYPE_BOOL,
             "Subtract thermal background from input cube."
@@ -519,7 +528,7 @@ static int kmos_sci_red(cpl_parameterlist * parlist, cpl_frameset * frameset)
     double scaling, conversion, f_0, zpoint, dit ;
     int print_once, cube_counter_data, cube_counter_noise, do_sky_subtraction,
         suppress_index, mapping_id, nb_science, nb_telluric, nb_illum_corr,
-        telluric_ok, actual_msg_level, nr_data, discard_subband ;
+        telluric_ok, actual_msg_level, nr_data, discard_subband, stretch ;
     int i, j, jj, sf, ifu_nr, sky_ifu_nr, det_nr, ifu_nr_telluric ;
     char                *   suffix ;
     char                *   mapping_mode ;
@@ -643,6 +652,8 @@ static int kmos_sci_red(cpl_parameterlist * parlist, cpl_frameset * frameset)
     par = cpl_parameterlist_find_const(parlist,
             "kmos.kmos_sci_red.discard_subband");
     discard_subband = cpl_parameter_get_bool(par);
+    par = cpl_parameterlist_find_const(parlist,"kmos.kmos_sci_red.stretch_sky");
+    stretch = cpl_parameter_get_int(par);
     par = cpl_parameterlist_find_const(parlist,"kmos.kmos_sci_red.tbsub");
     tbsub = cpl_parameter_get_bool(par);
     par = cpl_parameterlist_find_const(parlist, "kmos.kmos_sci_red.oscan");
@@ -744,7 +755,7 @@ static int kmos_sci_red(cpl_parameterlist * parlist, cpl_frameset * frameset)
     }
 
     /* Identify the RAW and CALIB frames in the input frameset */
-    if (kmo_dfs_set_groups(frameset, "kmos_sci_red") != 1) {
+    if (kmo_dfs_set_groups(frameset) != 1) {
         cpl_msg_error(__func__, "Cannot identify RAW and CALIB frames") ;
         cpl_error_set(__func__, CPL_ERROR_ILLEGAL_INPUT) ;
         return -1 ;
@@ -1126,7 +1137,7 @@ static int kmos_sci_red(cpl_parameterlist * parlist, cpl_frameset * frameset)
                     /* Apply the SKY tweaking */
                     tmp_cube2 = kmos_priv_sky_tweak(cube_data[ifu_nr-1], 
                             tmp_cube1,header_data[ifu_nr-1], .3, tbsub,
-                            ifu_nr, discard_subband);
+                            ifu_nr, discard_subband, stretch, 0);
                     cpl_imagelist_delete(cube_data[ifu_nr-1]); 
                     cpl_imagelist_delete(tmp_cube1); 
                     cube_data[ifu_nr-1] = tmp_cube2 ;
