@@ -154,10 +154,25 @@ static int kmos_sky_tweak_create(cpl_plugin *plugin)
     cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
     cpl_parameterlist_append(recipe->parameters, p);
 
+    /* --stretch_sky */
+    p = cpl_parameter_new_value("kmos.kmos_sky_tweak.stretch_sky",
+            CPL_TYPE_INT, 
+            "Stretch sky in the sky tweaking (0-no,1-yes,2-force)",
+            "kmos.kmos_sky_tweak", 0);
+    cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "stretch");
+    cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
+    cpl_parameterlist_append(recipe->parameters, p);
+
+    /* --plot */
+    p = cpl_parameter_new_value("kmos.kmos_sky_tweak.plot",
+            CPL_TYPE_INT, "Enable plotting", "kmos.kmos_sky_tweak", 0);
+    cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "plot");
+    cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
+    cpl_parameterlist_append(recipe->parameters, p);
+
     /* --tbsub */
     p = cpl_parameter_new_value("kmos.kmos_sky_tweak.tbsub", CPL_TYPE_BOOL,
-            "Subtract thermal background from input cube."
-            "(TRUE (apply) or FALSE (don't apply)",
+            "Subtract thermal background from input cube",
             "kmos.kmos_sky_tweak", TRUE);
     cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "tbsub");
     cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
@@ -225,7 +240,8 @@ static int kmos_sky_tweak(
     const cpl_parameter *   par ;
     int                     ox, nr_object_frames, nr_obj_devices,
                             nr_sky_devices, ifu_nr, sky_index,
-                            obj_index, tbsub, reduce_ifu, discard_subband ;
+                            obj_index, tbsub, reduce_ifu, discard_subband,
+                            stretch,plot ;
     const char          *   obj_fn ;
     const char          *   sky_fn ;
     cpl_frame           **  object_frames ;
@@ -245,7 +261,7 @@ static int kmos_sky_tweak(
         cpl_error_set(__func__, CPL_ERROR_NULL_INPUT) ;
         return -1 ;
     }
-    if (cpl_frameset_count_tags(frameset, CUBE_OBJECT) == 0 && 
+    if (cpl_frameset_count_tags(frameset, CUBE_OBJECT) == 0 || 
             cpl_frameset_count_tags(frameset, CUBE_SKY) == 0) {
         cpl_msg_error(__func__, "Missing Inputs") ;
         cpl_error_set(__func__, CPL_ERROR_FILE_NOT_FOUND) ;
@@ -261,7 +277,7 @@ static int kmos_sky_tweak(
     nr_obj_devices = nr_sky_devices = sky_index = obj_index = 0 ;
 
     /* Identify the RAW and CALIB frames in the input frameset */
-    if (kmo_dfs_set_groups(frameset, "kmos_sky_tweak") != 1) {
+    if (kmo_dfs_set_groups(frameset) != 1) {
         cpl_msg_error(__func__, "Cannot identify RAW and CALIB frames") ;
         cpl_error_set(__func__, CPL_ERROR_ILLEGAL_INPUT) ;
         return -1 ;
@@ -275,6 +291,10 @@ static int kmos_sky_tweak(
     par = cpl_parameterlist_find_const(parlist, 
             "kmos.kmos_sky_tweak.discard_subband");
     discard_subband = cpl_parameter_get_bool(par);
+    par=cpl_parameterlist_find_const(parlist,"kmos.kmos_sky_tweak.stretch_sky");
+    stretch = cpl_parameter_get_int(par);
+    par = cpl_parameterlist_find_const(parlist, "kmos.kmos_sky_tweak.plot");
+    plot = cpl_parameter_get_int(par);
 
     nr_object_frames = cpl_frameset_count_tags(frameset, CUBE_OBJECT);
     object_frames = cpl_malloc(nr_object_frames * sizeof(cpl_frame*));
@@ -288,17 +308,17 @@ static int kmos_sky_tweak(
     }
 
     sky_frame = cpl_frameset_find(frameset, CUBE_SKY);
-    sky_fits_desc = kmo_identify_fits_header(
-            cpl_frame_get_filename(sky_frame));
+    sky_fits_desc = kmo_identify_fits_header(cpl_frame_get_filename(sky_frame));
     if (sky_fits_desc.ex_noise == TRUE) nr_sky_devices = sky_fits_desc.nr_ext/2;
     else                                nr_sky_devices = sky_fits_desc.nr_ext;
 
     sky_fn = cpl_frame_get_filename(sky_frame);
 
+    /* Look on the Object files */
     for (ox = 0; ox < nr_object_frames; ox++) {
         object_frame = object_frames[ox];
-        obj_fits_desc = kmo_identify_fits_header(
-                cpl_frame_get_filename(object_frame));
+        obj_fits_desc = 
+            kmo_identify_fits_header(cpl_frame_get_filename(object_frame));
         if (obj_fits_desc.ex_noise == TRUE) 
             nr_obj_devices = obj_fits_desc.nr_ext / 2;
         else 
@@ -314,6 +334,7 @@ static int kmos_sky_tweak(
         kmo_dfs_save_main_header(frameset, SKY_TWEAK, "", object_frame, 
                 main_header, parlist, cpl_func);
 
+        /* Loop on the IFUs */
         for (ifu_nr = 1; ifu_nr <= nr_obj_devices; ifu_nr++) {
             /* Compute only one ifu */
             if (reduce_ifu != 0 && reduce_ifu != ifu_nr) continue ;
@@ -342,7 +363,8 @@ static int kmos_sky_tweak(
                 obj_data=kmclipm_imagelist_load(obj_fn, CPL_TYPE_FLOAT,
                         obj_index);
                 tweaked_data = kmos_priv_sky_tweak(obj_data, sky_data, 
-                        sub_header, .3, tbsub, ifu_nr, discard_subband);
+                        sub_header, .3, tbsub, ifu_nr, discard_subband,
+                        stretch, plot);
                 cpl_imagelist_delete(obj_data);
                 cpl_imagelist_delete(sky_data);
             } else {
