@@ -70,7 +70,9 @@ class DataPlotterManager(object):
             reflex.RecipeParameter(recipe=self.recipe_name, displayName="no_subtract",
                     group="Sky Sub.", description="Don't sky subtract object and references"),
             reflex.RecipeParameter(recipe=self.recipe_name, displayName="sky_tweak",
-                    group="Sky Sub.", description="Use modified sky cube for sky subtraction.(TRUE (apply) or FALSE (don't apply)."),
+                    group="Sky Sub.", description="Use modified sky cube for sky subtraction (TRUE or FALSE)"),
+            reflex.RecipeParameter(recipe=self.recipe_name, displayName="stretch",
+                    group="Sky Sub.", description="Stretch the sky for sky subtraction (0-no, 1-yes or 2-force)"),
             reflex.RecipeParameter(recipe=self.recipe_name, displayName="velocity_offset",
                     group="Sky Sub.", description="Specify velocity offset correction in km/s for lambda scale."),
         ]
